4.5.3 (2025-01-23)
==================

For users
---------

- If Python is in version 3.9 or more, force to use waitress 3.0.2 for security
- If Python is older than 3.9, so a flawed Python, accept a flawed waitress

See https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/1091

For developers
--------------

- fix the problem with lxml related to HTML cleaning
- run black for Python code
- fix generation of documentation with sphinx
- GitLab CI: print pip version for debugging
- GitLab CI: multiples grafts (from CW 4.6 or more) to make it work again

4.5.2 (2023-12-18)
==================

👷 Bug fixes
-----------

- SMTP: don't override SMTP import by MockSMTP in testlib
- testlib: move devtools.testlib.MockSMTP and devtools.testlib.Email

4.5.1 (2023-12-11)
==================

👷 Bug fix
-----------

remove a typing import which break compatibility with python 3.7

4.5.0 (2023-12-08)
==================

🎉 New features
--------------

- display progressbar when importing data
- minor refactoring to export reverse indicator stuff

👷 Bug fixes
-----------

- content_negociation: add a restriction on request_method for "one_entity" and "one_entity_eid" routes (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/934)
- content_negociation: fix a typo in cubicweb.pyramid.rest_api.include_html condition (https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/934)
